@@ -15,6 +15,9 @@ def recursive_walk(od_field: OrderedDict):
             if 'attributes' in od_field[k].keys():
                 ret_df = recursive_walk(od_field[k])
                 d = {**d, **ret_df}
+            else:
+                obj = od_field['attributes']['type'].replace(" ", ".")
+                d[f'{obj}.{k}'] = ",\n".join([   f'{k}: {v}' for k, v in od_field[k].items() if v is not None])
         else:
             if k != 'attributes':
                 obj = od_field['attributes']['type'].replace(" ", ".")
