@@ -227,15 +227,25 @@ class Vn:
         self.networkPassword = self.networkPassword if networkPassword is None else networkPassword
         self.networkCountry = self.networkCountry if networkCountry is None else networkCountry
         
-        if (self.networkUserName and self.networkPassword and self.networkURL):
-            self.networkConnection = requests.post(self.networkURL + '/api/v17.0/auth?username=' + self.networkUserName + '&password=' + self.networkPassword)
-            if (self.networkConnection.json()['responseStatus'] == 'SUCCESS'):
+        if self.networkUserName and self.networkPassword and self.networkURL:
+            payload = {
+                'username': self.networkUserName,
+                'password': self.networkPassword
+            }
+            headers = {
+                'Content-Type': 'application/x-www-form-urlencoded'
+            }
+            
+            self.networkConnection = requests.post(self.networkURL + '/api/v29.0/auth', data=payload, headers=headers)
+            
+            if self.networkConnection.json()['responseStatus'] == 'SUCCESS':
                 self.sessionId = self.networkConnection.json()['sessionId']
                 self.userId = self.networkConnection.json()['userId']
                 self.networkId = self.networkConnection.json()['networkId']
             else:
                 raise Exception(self.networkConnection.json())
 
+
         
         self.APIheaders = {'authorization': self.sessionId}
         self.APIversionList = []
